==> blesta-5.10.2.zip: blesta/plugins/support_manager/language/da_dk/admin_tickets.php <==
<?php
/**
 * Admin Tickets
 *
 * @package blesta
 * @subpackage blesta.language.da_dk
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminTickets.!success.ticket_created'] = 'Billetten #%1$s er blevet åbnet med succes.';
$lang['AdminTickets.!success.ticket_updated'] = 'Billetten #%1$s er blevet opdateret.';
$lang['AdminTickets.!success.ticket_split'] = 'Billetten #%1$s er blevet delt i billetten #%2$s.';
$lang['AdminTickets.!success.ticket_merge'] = 'De valgte tickets er blevet flettet til ticket #%1$s.';
$lang['AdminTickets.!success.ticket_reassign'] = 'De valgte billetter er blevet omfordelt med succes.';
$lang['AdminTickets.!success.ticket_update_status'] = 'De valgte billetter er blevet opdateret.';
$lang['AdminTickets.!success.ticket_delete'] = 'De valgte billetter er blevet slettet.';
$lang['AdminTickets.!notice.no_departments_staff'] = 'Der er endnu ikke oprettet nogen medarbejdere og/eller afdelinger. Klik på %1$s ovenfor for at oprette en afdeling, eller %2$s for at tildele en medarbejder.';
$lang['AdminTickets.index.page_title'] = 'Support Manager > Billetter';
$lang['AdminTickets.add.page_title'] = 'Support Manager > Åbn billet';
$lang['AdminTickets.reply.page_title'] = 'Support Manager > Billet #%1$s';
$lang['AdminTickets.search.page_title'] = 'Søgeresultater for "%1$s"';
$lang['AdminTickets.text.unassigned'] = 'Ikke tildelt';
$lang['AdminTickets.index.category_open'] = 'Afventer svar fra personalet';
$lang['AdminTickets.index.category_awaiting_reply'] = 'Afventer svar fra kunden';
$lang['AdminTickets.index.category_in_progress'] = 'I gang';
$lang['AdminTickets.index.category_on_hold'] = 'I venteposition';
$lang['AdminTickets.index.category_closed'] = 'Lukket';
$lang['AdminTickets.index.category_trash'] = 'Affald';
$lang['AdminTickets.index.categorylink_createticket'] = 'Åben billet';
$lang['AdminTickets.index.boxtitle_tickets'] = 'Billetter';
$lang['AdminTickets.index.heading_code'] = 'Billetnummer';
$lang['AdminTickets.index.heading_client'] = 'Kunde';
$lang['AdminTickets.index.heading_priority'] = 'Prioritet';
$lang['AdminTickets.index.heading_department_name'] = 'Afdeling';
$lang['AdminTickets.index.heading_summary'] = 'Resumé';
$lang['AdminTickets.index.heading_assigned_staff'] = 'Tildelt til';
$lang['AdminTickets.index.heading_last_reply_date'] = 'Sidste svar';
$lang['AdminTickets.index.any'] = 'Enhver';
$lang['AdminTickets.index.minutes'] = '%1$s minutter';
$lang['AdminTickets.index.hour'] = '1 time';
$lang['AdminTickets.index.hours'] = '%1$s timer';
$lang['AdminTickets.index.field_ticket_number'] = 'Billetnummer';
$lang['AdminTickets.index.field_priority'] = 'Prioritet';
$lang['AdminTickets.index.field_department_id'] = 'Afdeling';
$lang['AdminTickets.index.field_summary'] = 'Resumé';
$lang['AdminTickets.index.field_assigned_staff'] = 'Tildelt til';
$lang['AdminTickets.index.field_last_reply'] = 'Sidste svar';
$lang['AdminTickets.index.unassigned'] = 'Ikke tildelt';
$lang['AdminTickets.index.last_reply_by'] = 'af';
$lang['AdminTickets.index.no_results'] = 'Der er i øjeblikket ingen billetter med denne status.';
$lang['AdminTickets.index.text_with_selected'] = 'Med udvalgte billetter, optræd:';
$lang['AdminTickets.index.text_into_ticket'] = 'Ind på billetten:';
$lang['AdminTickets.index.text_to_client'] = 'Til kunden:';
$lang['AdminTickets.index.text_to_status'] = 'Skift til:';
$lang['AdminTickets.index.ticket_number_placeholder'] = 'Billetnummer';
$lang['AdminTickets.index.text_no_tickets'] = 'Ingen åbne billetter fundet. Prøv at søge igen.';
$lang['AdminTickets.index.field_actionsubmit'] = 'Indsend';
$lang['AdminTickets.index.ticket_name'] = '#%1$s %2$s %3$s';
$lang['AdminTickets.index.ticket_email'] = '#%1$s %2$s';
$lang['AdminTickets.add.boxtitle_add'] = 'Åben billet';
$lang['AdminTickets.add.heading_search_client'] = 'Søg efter klienten';
$lang['AdminTickets.add.text_no_clients'] = 'Ingen klienter fundet. Prøv at søge igen.';
$lang['AdminTickets.add.heading_summary'] = 'Resumé';
$lang['AdminTickets.add.heading_client'] = 'Kunde';
$lang['AdminTickets.add.heading_department'] = 'Afdeling';
$lang['AdminTickets.add.heading_staff_id'] = 'Tildelt til';
$lang['AdminTickets.add.heading_priority'] = 'Prioritet';
$lang['AdminTickets.add.heading_status'] = 'Status';
$lang['AdminTickets.add.field_attachments'] = 'Vedhæftede filer';
$lang['AdminTickets.add.field_details'] = 'Detaljer';
$lang['AdminTickets.add.text_add_attachment'] = 'Tilføj vedhæftet fil';
$lang['AdminTickets.add.field_addsubmit'] = 'Åben billet';
$lang['Admintickets.add.client_placeholder'] = 'Kunde-ID eller navn';
$lang['AdminTickets.add.text_add_response'] = 'Indsæt et foruddefineret svar';
$lang['AdminTickets.add.dropzone_drop_files_here'] = 'Læg filer her for at uploade eller klik for at vælge filer';
$lang['AdminTickets.add.dropzone_remove_file'] = 'Fjern fil';
$lang['AdminTickets.reply.boxtitle_reply'] = 'Billet #%1$s';
$lang['AdminTickets.reply.heading_summary'] = 'Resumé';
$lang['AdminTickets.reply.heading_client'] = 'Kunde';
$lang['AdminTickets.reply.heading_department'] = 'Afdeling';
$lang['AdminTickets.reply.heading_staff_id'] = 'Tildelt til';
$lang['AdminTickets.reply.heading_priority'] = 'Prioritet';
$lang['AdminTickets.reply.heading_status'] = 'Status';
$lang['AdminTickets.reply.heading_date_added'] = 'Dato for åbning';
$lang['AdminTickets.reply.text_add_response'] = 'Indsæt et foruddefineret svar';
$lang['AdminTickets.reply.text_with_selected'] = 'Udfør med udvalgte svar:';
$lang['AdminTickets.reply.heading_reply'] = 'Tilføj svar';
$lang['AdminTickets.reply.field_reply'] = 'Svar';
$lang['AdminTickets.reply.field_note'] = 'Bemærk';
$lang['AdminTickets.reply.field_attachments'] = 'Vedhæftede filer';
$lang['AdminTickets.reply.text_add_attachment'] = 'Tilføj vedhæftet fil';
$lang['AdminTickets.reply.field_replysubmit'] = 'Opdater billet';
$lang['AdminTickets.reply.field_actionsubmit'] = 'Gå';
$lang['AdminTickets.reply.refresh'] = 'Der er nye svar eller statusændringer.';
$lang['AdminTickets.reply.refresh_link'] = 'Klik for at vise.';
$lang['AdminTickets.reply.reply_date'] = 'Den %1$s %2$s %3$s svarede';
$lang['AdminTickets.reply.log_date'] = '%1$s af %2$s %3$s';
$lang['AdminTickets.reply.system'] = 'System';
$lang['AdminTickets.reply.staff_title'] = 'Støttepersonale';
$lang['AdminTickets.reply.dropzone_drop_files_here'] = 'Læg filer her for at uploade eller klik for at vælge filer';
$lang['AdminTickets.reply.dropzone_remove_file'] = 'Fjern fil';
$lang['AdminTickets.client.category_open'] = 'Afventer svar fra personalet';
$lang['AdminTickets.client.category_awaiting_reply'] = 'Afventer svar fra kunden';
$lang['AdminTickets.client.category_in_progress'] = 'I gang';
$lang['AdminTickets.client.category_on_hold'] = 'I venteposition';
$lang['AdminTickets.client.category_closed'] = 'Lukket';
$lang['AdminTickets.client.category_trash'] = 'Affald';
$lang['AdminTickets.client.categorylink_createticket'] = 'Åben billet';
$lang['AdminTickets.client.boxtitle_tickets'] = 'Billetter';
$lang['AdminTickets.client.heading_code'] = 'Billetnummer';
$lang['AdminTickets.client.heading_priority'] = 'Prioritet';
$lang['AdminTickets.client.heading_department_name'] = 'Afdeling';
$lang['AdminTickets.client.heading_summary'] = 'Resumé';
$lang['AdminTickets.client.heading_last_reply_date'] = 'Sidste svar';
$lang['AdminTickets.client.no_results'] = 'Der er i øjeblikket ingen billetter med denne status.';
$lang['AdminTickets.search.boxtitle_tickets'] = 'Søg efter billetter til "%1$s"';
$lang['AdminTickets.search.heading_code'] = 'Billetnummer';
$lang['AdminTickets.search.heading_priority'] = 'Prioritet';
$lang['AdminTickets.search.heading_status'] = 'Status';
$lang['AdminTickets.search.heading_department_name'] = 'Afdeling';
$lang['AdminTickets.search.heading_summary'] = 'Resumé';
$lang['AdminTickets.search.heading_last_reply_date'] = 'Sidste svar';
$lang['AdminTickets.search.no_results'] = 'Der er ingen billetter, der matcher søgekriterierne.';

==> blesta-5.11.4.zip: blesta/plugins/support_manager/language/da_dk/admin_tickets.php <==
<?php
/**
 * Admin Tickets
 *
 * @package blesta
 * @subpackage blesta.language.da_dk
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminTickets.!success.ticket_created'] = 'Billetten #%1$s er blevet åbnet med succes.';
$lang['AdminTickets.!success.ticket_updated'] = 'Billetten #%1$s er blevet opdateret.';
$lang['AdminTickets.!success.ticket_split'] = 'Billetten #%1$s er blevet delt i billetten #%2$s.';
$lang['AdminTickets.!success.ticket_merge'] = 'De valgte tickets er blevet flettet til ticket #%1$s.';
$lang['AdminTickets.!success.ticket_reassign'] = 'De valgte billetter er blevet omfordelt med succes.';
$lang['AdminTickets.!success.ticket_update_status'] = 'De valgte billetter er blevet opdateret.';
$lang['AdminTickets.!success.ticket_delete'] = 'De valgte billetter er blevet slettet.';
$lang['AdminTickets.!notice.no_departments_staff'] = 'Der er endnu ikke oprettet nogen medarbejdere og/eller afdelinger. Klik på %1$s ovenfor for at oprette en afdeling, eller %2$s for at tildele en medarbejder.';
$lang['AdminTickets.index.page_title'] = 'Support Manager > Billetter';
$lang['AdminTickets.add.page_title'] = 'Support Manager > Åbn billet';
$lang['AdminTickets.reply.page_title'] = 'Support Manager > Billet #%1$s';
$lang['AdminTickets.search.page_title'] = 'Søgeresultater for "%1$s"';
$lang['AdminTickets.text.unassigned'] = 'Ikke tildelt';
$lang['AdminTickets.index.category_open'] = 'Afventer svar fra personalet';
$lang['AdminTickets.index.category_awaiting_reply'] = 'Afventer svar fra kunden';
$lang['AdminTickets.index.category_in_progress'] = 'I gang';
$lang['AdminTickets.index.category_on_hold'] = 'I venteposition';
$lang['AdminTickets.index.category_closed'] = 'Lukket';
$lang['AdminTickets.index.category_trash'] = 'Affald';
$lang['AdminTickets.index.categorylink_createticket'] = 'Åben billet';
$lang['AdminTickets.index.boxtitle_tickets'] = 'Billetter';
$lang['AdminTickets.index.heading_code'] = 'Billetnummer';
$lang['AdminTickets.index.heading_client'] = 'Kunde';
$lang['AdminTickets.index.heading_priority'] = 'Prioritet';
$lang['AdminTickets.index.heading_department_name'] = 'Afdeling';
$lang['AdminTickets.index.heading_summary'] = 'Resumé';
$lang['AdminTickets.index.heading_assigned_staff'] = 'Tildelt til';
$lang['AdminTickets.index.heading_last_reply_date'] = 'Sidste svar';
$lang['AdminTickets.index.any'] = 'Enhver';
$lang['AdminTickets.index.minutes'] = '%1$s minutter';
$lang['AdminTickets.index.hour'] = '1 time';
$lang['AdminTickets.index.hours'] = '%1$s timer';
$lang['AdminTickets.index.field_ticket_number'] = 'Billetnummer';
$lang['AdminTickets.index.field_priority'] = 'Prioritet';
$lang['AdminTickets.index.field_department_id'] = 'Afdeling';
$lang['AdminTickets.index.field_summary'] = 'Resumé';
$lang['AdminTickets.index.field_assigned_staff'] = 'Tildelt til';
$lang['AdminTickets.index.field_last_reply'] = 'Sidste svar';
$lang['AdminTickets.index.unassigned'] = 'Ikke tildelt';
$lang['AdminTickets.index.last_reply_by'] = 'af';
$lang['AdminTickets.index.no_results'] = 'Der er i øjeblikket ingen billetter med denne status.';
$lang['AdminTickets.index.text_with_selected'] = 'Med udvalgte billetter, optræd:';
$lang['AdminTickets.index.text_into_ticket'] = 'Ind på billetten:';
$lang['AdminTickets.index.text_to_client'] = 'Til kunden:';
$lang['AdminTickets.index.text_to_status'] = 'Skift til:';
$lang['AdminTickets.index.ticket_number_placeholder'] = 'Billetnummer';
$lang['AdminTickets.index.text_no_tickets'] = 'Ingen åbne billetter fundet. Prøv at søge igen.';
$lang['AdminTickets.index.field_actionsubmit'] = 'Indsend';
$lang['AdminTickets.index.ticket_name'] = '#%1$s %2$s %3$s';
$lang['AdminTickets.index.ticket_email'] = '#%1$s %2$s';
$lang['AdminTickets.add.boxtitle_add'] = 'Åben billet';
$lang['AdminTickets.add.heading_search_client'] = 'Søg efter klienten';
$lang['AdminTickets.add.text_no_clients'] = 'Ingen klienter fundet. Prøv at søge igen.';
$lang['AdminTickets.add.heading_summary'] = 'Resumé';
$lang['AdminTickets.add.heading_client'] = 'Kunde';
$lang['AdminTickets.add.heading_department'] = 'Afdeling';
$lang['AdminTickets.add.heading_staff_id'] = 'Tildelt til';
$lang['AdminTickets.add.heading_priority'] = 'Prioritet';
$lang['AdminTickets.add.heading_status'] = 'Status';
$lang['AdminTickets.add.field_attachments'] = 'Vedhæftede filer';
$lang['AdminTickets.add.field_details'] = 'Detaljer';
$lang['AdminTickets.add.text_add_attachment'] = 'Tilføj vedhæftet fil';
$lang['AdminTickets.add.field_addsubmit'] = 'Åben billet';
$lang['Admintickets.add.client_placeholder'] = 'Kunde-ID eller navn';
$lang['AdminTickets.add.text_add_response'] = 'Indsæt et foruddefineret svar';
$lang['AdminTickets.add.dropzone_drop_files_here'] = 'Læg filer her for at uploade eller klik for at vælge filer';
$lang['AdminTickets.add.dropzone_remove_file'] = 'Fjern fil';
$lang['AdminTickets.reply.boxtitle_reply'] = 'Billet #%1$s';
$lang['AdminTickets.reply.heading_summary'] = 'Resumé';
$lang['AdminTickets.reply.heading_client'] = 'Kunde';
$lang['AdminTickets.reply.heading_department'] = 'Afdeling';
$lang['AdminTickets.reply.heading_staff_id'] = 'Tildelt til';
$lang['AdminTickets.reply.heading_priority'] = 'Prioritet';
$lang['AdminTickets.reply.heading_status'] = 'Status';
$lang['AdminTickets.reply.heading_date_added'] = 'Dato for åbning';
$lang['AdminTickets.reply.text_add_response'] = 'Indsæt et foruddefineret svar';
$lang['AdminTickets.reply.text_with_selected'] = 'Udfør med udvalgte svar:';
$lang['AdminTickets.reply.heading_reply'] = 'Tilføj svar';
$lang['AdminTickets.reply.field_reply'] = 'Svar';
$lang['AdminTickets.reply.field_note'] = 'Bemærk';
$lang['AdminTickets.reply.field_attachments'] = 'Vedhæftede filer';
$lang['AdminTickets.reply.text_add_attachment'] = 'Tilføj vedhæftet fil';
$lang['AdminTickets.reply.field_replysubmit'] = 'Opdater billet';
$lang['AdminTickets.reply.field_actionsubmit'] = 'Gå';
$lang['AdminTickets.reply.refresh'] = 'Der er nye svar eller statusændringer.';
$lang['AdminTickets.reply.refresh_link'] = 'Klik for at vise.';
$lang['AdminTickets.reply.reply_date'] = 'Den %1$s %2$s %3$s svarede';
$lang['AdminTickets.reply.log_date'] = '%1$s af %2$s %3$s';
$lang['AdminTickets.reply.system'] = 'System';
$lang['AdminTickets.reply.staff_title'] = 'Støttepersonale';
$lang['AdminTickets.reply.dropzone_drop_files_here'] = 'Læg filer her for at uploade eller klik for at vælge filer';
$lang['AdminTickets.reply.dropzone_remove_file'] = 'Fjern fil';
$lang['AdminTickets.client.category_open'] = 'Afventer svar fra personalet';
$lang['AdminTickets.client.category_awaiting_reply'] = 'Afventer svar fra kunden';
$lang['AdminTickets.client.category_in_progress'] = 'I gang';
$lang['AdminTickets.client.category_on_hold'] = 'I venteposition';
$lang['AdminTickets.client.category_closed'] = 'Lukket';
$lang['AdminTickets.client.category_trash'] = 'Affald';
$lang['AdminTickets.client.categorylink_createticket'] = 'Åben billet';
$lang['AdminTickets.client.boxtitle_tickets'] = 'Billetter';
$lang['AdminTickets.client.heading_code'] = 'Billetnummer';
$lang['AdminTickets.client.heading_priority'] = 'Prioritet';
$lang['AdminTickets.client.heading_department_name'] = 'Afdeling';
$lang['AdminTickets.client.heading_summary'] = 'Resumé';
$lang['AdminTickets.client.heading_last_reply_date'] = 'Sidste svar';
$lang['AdminTickets.client.no_results'] = 'Der er i øjeblikket ingen billetter med denne status.';
$lang['AdminTickets.search.boxtitle_tickets'] = 'Søg efter billetter til "%1$s"';
$lang['AdminTickets.search.heading_code'] = 'Billetnummer';
$lang['AdminTickets.search.heading_priority'] = 'Prioritet';
$lang['AdminTickets.search.heading_status'] = 'Status';
$lang['AdminTickets.search.heading_department_name'] = 'Afdeling';
$lang['AdminTickets.search.heading_summary'] = 'Resumé';
$lang['AdminTickets.search.heading_last_reply_date'] = 'Sidste svar';
$lang['AdminTickets.search.no_results'] = 'Der er ingen billetter, der matcher søgekriterierne.';
$lang['AdminTickets.reply.text_contacts'] = 'Kontakter, der ikke er valgt, tilføjes automatisk til billetten, hvis de svarer på den.';
$lang['AdminTickets.reply.text_add_recipient'] = 'Tilføj modtager';
$lang['AdminTickets.reply.heading_contacts'] = 'Kontaktpersoner';
$lang['AdminTickets.reply.heading_recipients'] = 'Modtagere';
$lang['AdminTickets.add.text_contacts'] = 'Kontakter, der ikke er valgt, tilføjes automatisk til billetten, hvis de svarer på den.';
$lang['AdminTickets.add.text_add_recipient'] = 'Tilføj modtager';
$lang['AdminTickets.add.heading_contacts'] = 'Kontaktpersoner';
$lang['AdminTickets.add.heading_recipients'] = 'Modtagere';
